#!/bin/bash

# Dump & restore HADMIN database without keeping the logs.
# Version Beta 1, PHiL 03/11/2004

#catch Slis version
SLIS_VERSION=`cat /etc/version_slis_num`

if [  "$SLIS_VERSION" = "3.0" -o "$SLIS_VERSION" = "3.1" ]
then
	echo "Slis V3.X found."
	echo "Attempting to dump and restore the database..."
else
	echo "ERR: Not supported version (Slis V3.X only script)"
	echo "Exiting..."
	exit 1
fi

#
# here we goes with a V3.X Slis version.
#

# Check for free room on the /tmp folder (1 MB is wished)
if [ "`df | grep /tmp | awk '{print $4}'`" -lt "1000" ]
then
	echo "ERR: not enougth space on /tmp to dump the database"
	echo "Exiting..."
	exit 2
fi
	

# Set variable usefull variables
if [ ! \( -f /home/hadmin/html/config_pgsql.inc.php \) ]
then
	echo "ERR: file /home/hadmin/html/config_pgsql.inc.php doesn't exist"
	echo "Exiting..."
	exit 3
fi
SLIS_POSTGRESUSER=`cat /home/hadmin/html/config_pgsql.inc.php | grep "POSTGRESUSER" | cut -d\" -f2`
SLIS_POSTGRESPASS=`cat /home/hadmin/html/config_pgsql.inc.php | grep "POSTGRESPASS" | cut -d\" -f2`
SLIS_HADMINUSER=`cat /home/hadmin/html/config_pgsql.inc.php | grep "ADMINUSER" | cut -d\" -f2`
SLIS_HADMINPASS=`cat /home/hadmin/html/config_pgsql.inc.php | grep "ADMINPASS" | cut -d\" -f2`


# Delete old dump datas before strating.
rm -f /tmp/hadmin_databases.sql 2>/dev/null


# Stop the Apache server, database is locked if Apache running
service httpd stop

# Dump the schema of the database
# Must do it with the DB owner
export PGUSER=$SLIS_HADMINUSER
export PGPASSWORD=$SLIS_HADMINPASS

echo "Start dumping the schema and the datas of hadmin"
pg_dump -d -R hadmin | grep -v "INSERT INTO access_squid " | grep -v "INSERT INTO access_apache " | grep -v "INSERT INTO \"access_squid\" " | grep -v "INSERT INTO \"access_apache\" "  > /tmp/hadmin_database.sql

if [ $? != "0" ]
then
	echo "ERR: Could not dump the database hadmin, maybe corrupted SGBD ?"
	echo "Exiting..."
	exit 4
else
	echo "hadmin database saved."
fi


# Here we have the database dumped.
# We are SURE the datas aren't corrupted.
#


# Destroy the current database

# Switch to priviledge user
export PGUSER=$SLIS_POSTGRESUSER
export PGPASSWORD=$SLIS_POSTGRESPASS

# Connect to another DB for not lock the hadmin, and then, delete hadmin
echo "drop database hadmin;" | psql template1 > /dev/null 2>&1

if [ $? != "0" ]
then
	echo "ERR: error while deleting database hadmin, please check the SGBD health !!!"
	echo "Exiting..."
	exit 6
else
	echo "Database hadmin deleted."
fi

# Create the hadmin database
echo "create database hadmin;" | psql template1 > /dev/null 2>&1

if [ $? != "0" ]
then
	echo "ERR: error while creating database hadmin. "
	echo "ERR: in this state the hadmin database is BROKEN !!!"
	echo "ERR: go in /tmp and restore manualy the hadmin_database.sql file"
	echo "Exiting..."
	exit 7
else
	echo "Database hadmin created."
fi


# Write the schema of the database hadmin
# Must do it with the DB owner
export PGUSER=$SLIS_HADMINUSER
export PGPASSWORD=$SLIS_HADMINPASS

echo "\\i /tmp/hadmin_database.sql" | psql hadmin  > /dev/null 2>&1

if [ $? != "0" ]
then
	echo "ERR: error while restoring the datas of the database hadmin !!!"
	echo "ERR: in this state the hadmin database is BROKEN !!!"
	echo "ERR: go in /tmp and restore manualy the hadmin_database.sql file"
	echo "Exiting..."
	exit 8
else
	echo "hadmin database restored."
fi


# Start again apache server
service httpd start

# Finish !
echo "Dump & restore of database hadmin SUCCESFULLY."
